/*
 * defs.h
 *
 *
 */



#define PACKAGE    "9tree-puzzle"
#define VERSION    "5.2-Plan9.0.02"
#define DATE       "May 2007"

#define STDOUT stdout

/* time check interval in seconds for ML/puzzling step status (900 = 15min) */
#  define TIMECHECK_INTERVAL 900

/* filenames */
#  define FILENAMELENGTH 2048

/* maximum exp difference, such that 1.0+exp(-TP_MAX_EXP_DIFF) == 1.0 */
#  define TP_MAX_EXP_DIFF 40

#  define INFILEDEFAULT     "infile"
#  define OUTFILEDEFAULT    "outfile"
#  define TREEFILEDEFAULT   "outtree"
#  define INTREEDEFAULT     "intree"
#  define DISTANCESDEFAULT  "outdist"
#  define TRIANGLEDEFAULT   "outlm.eps"
#  define UNRESOLVEDDEFAULT "outqlist"
#  define ALLQUARTDEFAULT   "outallquart"
#  define ALLQUARTLHDEFAULT "outallquartlh"
#  define SITELHDEFAULT     "outsitelh"
#  define SITELHBDEFAULT    "outsitelhb"
#  define SITERATEDEFAULT   "outsiterate"
#  define SITERATEBDEFAULT  "outsiterateb"
#  define OUTPARAMDEFAULT   "outparam"
#  define SUBSETDEFAULT     "insubsetmatr"
#  define OUTPTLISTDEFAULT  "outpstep"
#  define OUTPTORDERDEFAULT "outptorder"

#define OUTFILEEXT    "puzzle"
#define TREEFILEEXT   "tree"
#define TEMPFILEEXT   "temp"
#define DISTANCESEXT  "dist"
#define TRIANGLEEXT   "eps"
#define UNRESOLVEDEXT "qlist"
#define ALLQUARTEXT   "allquart"
#define ALLQUARTLHEXT "allquartlh"
#define SITELHEXT     "sitelh"
#define SITELHBEXT    "sitelhb"
#define SITERATEEXT   "siterate"
#define SITERATEBEXT  "siterateb"
#define OUTPARAMEXT   "param"
#define SUBSETEXT     "subsetmatr"
#define OUTPTLISTEXT  "pstep"
#define OUTPTORDEREXT "ptorder"


/* resetprefix values  (xxx) */
#define RESET_NONE   0
#define RESET_INFILE 1
#define RESET_INTREE 2

/* setprefix_optn values  (xxx) */
#define SETPREFIX_NONE   0
#define SETPREFIX_INFILE 1
#define SETPREFIX_INTREE 2
#define SETPREFIX_RESET  3
#define SETPREFIX_PREFIX 4

/* auto_aamodel/auto_datatype values  (xxx) */
#define AUTO_OFF      0
#define AUTO_GUESS    1
#define AUTO_DEFAULT  2


/* qptlist values  (xxx) */
#define PSTOUT_NONE      0
#define PSTOUT_ORDER     1
#define PSTOUT_LISTORDER 2
#define PSTOUT_LIST      3

/* dtat_optn values  (xxx) */
#define NUCLEOTIDE 0
#define AMINOACID  1
#define BINARY     2

/* typ_optn values  (xxx) */
#define TREERECON_OPTN 0
#define LIKMAPING_OPTN 1
#define NUMTYPES 2

/* puzzlemodes (xxx) */
#define QUARTPUZ 0
#define USERTREE 1
#define CONSENSUS 2
#define PAIRDIST 3
#define NUMPUZZLEMODES 4

/* modes for rootsearch (xxx) */
#define ROOT_USER 0
#define ROOT_AUTO 1
#define ROOT_DISPLAYED 2
#define NUMROOTSEARCH 3


/* defines for types of quartet likelihood computation (xxx) */
#define EXACT  0
#define APPROX 1

/* defines for results of sequence number check (seqnumcheck) */
#define SEQNUM_OK 0
#define SEQNUM_TOOFEW 1
#define SEQNUM_TOOMANY 2

/* definitions for writing output */
#define WRITEALL    0
#define WRITEPARAMS 1
#define WRITEREST   2

/* definitions for timing */

#define OVERALL   0
#define GENERAL   1
#define OPTIONS   2
#define PARAMEST  3
#define QUARTETS  4
#define PUZZLING  5
#define TREEEVAL  6

typedef struct {
	int      currentjob;
	clock_t  tempcpu;
	clock_t  tempfullcpu;
	clock_t  tempcpustart;
	time_t   temptime;
	time_t   tempfulltime;
	time_t   temptimestart;

        clock_t  maxcpu;
	clock_t  mincpu;
	time_t   maxtime;
	time_t   mintime;

	double   maxcpublock;
	double   mincpublock;
	double   mincputick;
	double   mincputicktime;
	double   maxtimeblock;
	double   mintimeblock;

	double   generalcpu;
	double   optionscpu;
	double   paramestcpu;
	double   quartcpu;
	double   quartblockcpu;
	double   quartmaxcpu;
	double   quartmincpu;
	double   puzzcpu;
	double   puzzblockcpu;
	double   puzzmaxcpu;
	double   puzzmincpu;
	double   treecpu;
	double   treeblockcpu;
	double   treemaxcpu;
	double   treemincpu;
	double   cpu;
	double   fullcpu;

	double   generaltime;
	double   optionstime;
	double   paramesttime;
	double   quarttime;
	double   quartblocktime;
	double   quartmaxtime;
	double   quartmintime;
	double   puzztime;
	double   puzzblocktime;
	double   puzzmaxtime;
	double   puzzmintime;
	double   treetime;
	double   treeblocktime;
	double   treemaxtime;
	double   treemintime;
	double   time;
	double   fulltime;
} timearray_t;

